[−][src]Crate nnsplit
Fast, robust sentence splitting with bindings for Python, Rust and Javascript. This crate contains the core splitting logic which is shared between Javascript, Python and Rust. Each binding then implements a backend separately.
See tch_rs_backend::NNSplit for information for using NNSplit from Rust.
Structs
| Level | A Split level, used to describe what this split corresponds to (e. g. a sentence). |
| NNSplitLogic | The logic by which texts are split. |
| NNSplitOptions | Options for splitting text. |
| SplitSequence | Instructions for how to convert neural network outputs and a text to |
Enums
| Split | A splitted text. |
| SplitInstruction | Instruction to split text. |